==> haskell-bower-json-1.0.0.1-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-CHUoPnadjuM5jfUW5BbI4A
key: bower-json-1.0.0.1-CHUoPnadjuM5jfUW5BbI4A
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: 217eb1a51cd902413434b427957acc14
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-CHUoPnadjuM5jfUW5BbI4A
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv
    deepseq-1.4.3.0 aeson-better-errors-0.9.1.0-z7IVSaApEE6Ipnv9HNKvb
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
    scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA transformers-0.5.2.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv=cb689fc7acd6290bc554164c78e4d251
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             aeson-better-errors-0.9.1.0-z7IVSaApEE6Ipnv9HNKvb=b30e6ba96c0077b32166dff01d75f6d6
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw=11abcce15758b0e3fff5fe5ecd138e8b
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-45-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-DxBzc8gwOvNJ2CP24KEq0f
key: bower-json-1.0.0.1-DxBzc8gwOvNJ2CP24KEq0f
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
abi: fa4fb0cf6a4e6905949930da21be1eec
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-DxBzc8gwOvNJ2CP24KEq0f
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD
    deepseq-1.4.3.0 aeson-better-errors-0.9.1.0-EWJEqwNzMaKCcI5aDWMN4J
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA transformers-0.5.2.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD=2daf6700d9ef385ba2659a6e8aebe988
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             aeson-better-errors-0.9.1.0-EWJEqwNzMaKCcI5aDWMN4J=8bfbec347317c241dfbd92b07459c47a
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
